@@ -6,18 +6,21 @@
 # License: wxWindows License                                                  #
 ###############################################################################
 
-"""
+"""@package Editra.src.ed_ipc
+
 Classes and utilities for handling IPC between running instances of Editra. The
 IPC is done through sockets using the TCP protocol. Message packets have a
 specified format and authentication method that is described in L{EdIpcServer}.
 
-Remote Control Protocol:
+@section protocol Remote Control Protocol:
 
 This server and its relationship with the main application object allows for
 some limited remote control of Editra. The server's basic message protocol
 requirements are as follows.
 
+@verbatim
 SESSION_KEY;xml;MSGEND
+@endverbatim
 
 Where the SESSION_KEY is the unique authentication key created by the app that
 started the server. This key is stored in the user profile and only valid for
@@ -26,8 +29,8 @@ string defined in this file (*EDEND*). If both of these parts of the message
 are found and correct the server will forward the messages that are packed in
 between to the app.
 
-Message Format:
-
+@section format Message Format:
+@verbatim
 <edipc>
    <filelist>
       <file name="absolute_filepath"/>
@@ -36,14 +39,13 @@ Message Format:
       <arg name="g" value="2"/>
    </arglist>
 </edipc>
-
-@summary: Editra's IPC Library
+@endverbatim
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_ipc.py 67123 2011-03-04 00:02:35Z CJP $"
-__revision__ = "$Revision: 67123 $"
+__svnid__ = "$Id: ed_ipc.py 71718 2012-06-12 13:25:48Z CJP $"
+__revision__ = "$Revision: 71718 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -56,7 +58,7 @@ import time
 
 # Editra Libs
 import util
-import syntax
+import ed_xml
 import ebmlib
 
 #-----------------------------------------------------------------------------#
@@ -64,14 +66,14 @@ import ebmlib
 
 # Port choosing algorithm ;)
 EDPORT = (10 * int('ed', 16) + sum(ord(x) for x in "itr") + int('a', 16)) * 10
-MSGEND = u"*EDEND*"
+MSGEND = "*EDEND*"
 
 # Xml Implementation
-EDXML_IPC       = u"edipc"
-EDXML_FILELIST  = u"filelist"
-EDXML_FILE      = u"file"
-EDXML_ARGLIST   = u"arglist"
-EDXML_ARG       = u"arg"
+EDXML_IPC       = "edipc"
+EDXML_FILELIST  = "filelist"
+EDXML_FILE      = "file"
+EDXML_ARGLIST   = "arglist"
+EDXML_ARG       = "arg"
 
 #-----------------------------------------------------------------------------#
 
@@ -165,7 +167,7 @@ class EdIpcServer(threading.Thread):
 
                 # Block for up to 2 seconds while reading
                 start = time.time()
-                recieved = u''
+                recieved = ''
                 while time.time() < start + 2:
                     recieved += client.recv(4096)
                     if recieved.endswith(MSGEND):
@@ -175,16 +177,18 @@ class EdIpcServer(threading.Thread):
                 # the input and dispatch to the app.
                 if recieved.startswith(self.__key) and recieved.endswith(MSGEND):
                     # Strip the key
-                    recieved = recieved.replace(self.__key, u'', 1)
+                    recieved = recieved.replace(self.__key, '', 1)
                     # Strip the end token
-                    xmlstr = recieved.rstrip(MSGEND).strip(u";")
+                    xmlstr = recieved.rstrip(MSGEND).strip(";")
 
                     # Parse the xml
                     exml = IPCCommand()
                     try:
-                        # Well formed xml must be utf-8 string not unicode
+                        # Well formed xml must be utf-8 string not Unicode
+                        if not ebmlib.IsUnicode(xmlstr):
+                            xmlstr = unicode(xmlstr, sys.getfilesystemencoding())
                         xmlstr = xmlstr.encode('utf-8')
-                        exml.LoadFromString(xmlstr)
+                        exml = IPCCommand.parse(xmlstr)
                     except Exception, msg:
                         # Log and ignore parsing errors
                         logmsg = "[ed_ipc][err] Parsing failed: %s\n" % msg
@@ -216,25 +220,25 @@ def SendCommands(xmlobj, key):
     @return: bool
 
     """
-    assert isinstance(xmlobj, syntax.EditraXml), "SendCommands expects an xml object"
+    assert isinstance(xmlobj, ed_xml.EdXml), "SendCommands expects an xml object"
 
     # Build the edipc protocol msg
     cmds = list()
     cmds.insert(0, key)
     cmds.append(xmlobj.GetXml())
     cmds.append(MSGEND)
-
     try:
         # Setup the client socket
         client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         client.connect(('127.0.0.1', EDPORT))
 
         # Server expects commands delimited by ;
-        message = u";".join(cmds)
+        message = ";".join(cmds)
         client.send(message)
         client.shutdown(socket.SHUT_RDWR)
         client.close()
     except Exception, msg:
+        util.Log("[ed_ipc][err] Failed in SendCommands: %s" % msg)
         return False
     else:
         return True
@@ -242,161 +246,28 @@ def SendCommands(xmlobj, key):
 #-----------------------------------------------------------------------------#
 # Command Serialization
 
-class IPCCommand(syntax.EditraXml):
-    """Xml packet used for sending data to remote process through ipc"""
-    def __init__(self):
-        syntax.EditraXml.__init__(self)
-
-        # Attributes
-        self._files = IPCFileList()
-        self._args = IPCArgList()
-
-        # Setup
-        self.SetName(EDXML_IPC)
-        self.RegisterHandler(self._files)
-        self.RegisterHandler(self._args)
-
-    #---- Public Api ----#
-
-    def GetArgs(self):
-        """Get the list of paths
-        @return: list of tuples
-
-        """
-        return self._args.GetArgs()
-
-    def SetArgs(self, args):
-        """Set the files
-        @param flist: list of strings
-
-        """
-        self._args.SetArgs(args)
-
-    def GetFiles(self):
-        """Get the list of paths
-        @return: list of strings
-
-        """
-        return self._files.GetFiles()
-
-    def SetFiles(self, flist):
-        """Set the files
-        @param flist: list of strings
-
-        """
-        self._files.SetFiles(flist)
-
-class IPCFileList(syntax.EditraXml):
+class IPCFile(ed_xml.EdXml):
     """Xml object for holding the list of files
-
-    <filelist>
-       <file value="/path/to/file"/>
-    </filelist>
+    @verbatim <file value="/path/to/file"/> @endverbatim
 
     """
-    def __init__(self):
-        syntax.EditraXml.__init__(self)
+    class meta:
+        tagname = EDXML_FILE
+    value = ed_xml.String(required=True)
 
-        # Attributes
-        self._files = list()
-
-        # Setup
-        self.SetName(EDXML_FILELIST)
-
-    #---- Xml Implementation ----#
-
-    def startElement(self, name, attrs):
-        """Collect all the file elements"""
-        if name == EDXML_FILE:
-            fname = attrs.get(syntax.EXML_VALUE, None)
-            if fname is not None:
-                self._files.append(fname)
-
-    def GetSubElements(self):
-        """Get the objects subelements"""
-        xmlstr = u""
-        tmp = u"<%s %s=\"" % (EDXML_FILE, syntax.EXML_VALUE)
-        tmp += u"%s\"/>"
-        for fname in self._files:
-            if not ebmlib.IsUnicode(fname):
-                fname = fname.decode(sys.getfilesystemencoding())
-            xmlstr += tmp % fname
-        return xmlstr
-
-    #--- public api ----#
-
-    def GetFiles(self):
-        """Get the list of paths
-        @return: list of strings
-
-        """
-        return self._files
-
-    def SetFiles(self, flist):
-        """Set the list of files
-        @param flist: list of strings
-
-        """
-        self._files = flist
-
-class IPCArgList(syntax.EditraXml):
+class IPCArg(ed_xml.EdXml):
     """Xml object for holding the list of args
-
-    <arglist>
-       <arg name="test" value="x"/>
-    </arglist>
+    @verbatim <arg name="test" value="x"/> @endverbatim
 
     """
-    def __init__(self):
-        syntax.EditraXml.__init__(self)
+    class meta:
+        tagname = EDXML_ARG
+    name = ed_xml.String(required=True)
+    value = ed_xml.String(required=True)
 
-        # Attributes
-        self._args = list()
-
-        # Setup
-        self.SetName(EDXML_ARGLIST)
-
-    #---- Xml Implementation ----#
-
-    def startElement(self, name, attrs):
-        """Collect all the file elements"""
-        if name == EDXML_ARG:
-            arg = attrs.get(syntax.EXML_NAME, None)
-            val = attrs.get(syntax.EXML_VALUE, u'')
-            if not val.isdigit():
-                val = -1
-            else:
-                val = int(val)
-            if arg is not None:
-                self._args.append((arg, val))
-
-    def GetSubElements(self):
-        """Get the objects sub-elements"""
-        xmlstr = u""
-        tmp = u"<%s %s=\"" % (EDXML_ARG, syntax.EXML_NAME)
-        tmp += u"%s\" "
-        tmp += "%s=\"" % syntax.EXML_VALUE
-        tmp += "%s\"/>"
-        for argval in self._args:
-            xmlstr += tmp % argval
-        return xmlstr
-
-    #--- public api ----#
-
-    def GetArgs(self):
-        """Get the list of arguments (command line switches)
-        @return: list of tuples
-
-        """
-        return self._args
-
-    def SetArgs(self, args):
-        """Set the list of files
-        @param flist: list of tuples
-
-        """
-        assert isinstance(args, list)
-        for arg in args:
-            assert isinstance(arg, tuple)
-        self._args = args
-    
\ No newline at end of file
+class IPCCommand(ed_xml.EdXml):
+    """IPC XML Command"""
+    class meta:
+        tagname = EDXML_IPC
+    filelist = ed_xml.List(ed_xml.Model(IPCFile))
+    arglist = ed_xml.List(ed_xml.Model(IPCArg))
