@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 71182 2012-04-11 23:02:40Z CJP $"
-__revision__ = "$Revision: 71182 $"
+__svnid__ = "$Id: ed_pages.py 71668 2012-06-06 18:32:07Z CJP $"
+__revision__ = "$Revision: 71668 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -175,8 +175,11 @@ class EdPages(ed_book.EdBaseBook):
                 dlg.SetBitmap(bmp)
             dlg.CenterOnParent()
             result = dlg.ShowModal()
-            enc = dlg.GetEncoding()
-            dlg.Destroy()
+            if dlg:
+                enc = dlg.GetEncoding()
+                dlg.Destroy()
+            else:
+                result = wx.ID_CANCEL
 
             # Don't want to open it in another encoding
             if result == wx.ID_CANCEL:
